"use strict";

var argx = require('argx'),
    SrchLogger = require('./logging/srch_logger'),
    async = require('async');

var types = require('./types.json'),
    matchAnyProp = require('./matching/match_any_prop'),
    searchType = require('./searching/search_type');

/** @lends apemanSrch */
function apemanSrch(terms, options, callback) {
    var args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    options = args.pop('object') || {};
    terms = args.remain();

    var typeName = options.type;
    var logger = new SrchLogger({});
    async.waterfall([
        function (callback) {
            var invalid = typeName && !types[typeName];
            if (invalid) {
                callback(new Error('Unknown type: ' + typeName));
                return;
            }
            logger.logSearchStart();
            if (typeName) {
                searchType(types[typeName], callback);
            } else {
                async.eachSeries(Object.keys(types), function (typeName, callback) {
                    searchType(types[typeName], callback);
                }, callback);
            }
        },
        function (found, callback) {
            logger.logSearchDone();
            found = found.filter(function (found) {
                if (terms.length == 0) {
                    found.hit = true;
                    return found;
                }
                for (var i = 0, len = terms.length; i < len; i++) {
                    var term = terms[i];
                    var hit = matchAnyProp(found, term);
                    if (hit) {
                        found.hit = true;
                        found.hitTerm = term;
                        return found;
                    }
                }
                found.hit = false;
                return found;
            });
            logger.logSearched(found, terms);
            callback(null);
        }
    ], callback);
}


module.exports = apemanSrch;
