/**
 * List repository for an orgnization.
 * @function listOrgRepo
 * @param {string} name - Name of orgnization.
 * @param {function} callback - Callback when done.
 */

"use strict";

var _apiRequest = require('./_api_request'),
    util = require('util');

/** @lends listOrgRepo */
function listOrgRepo(name, callback) {
    var pathname = util.format("/orgs/%s/repos", name);
    _apiRequest(pathname, function (err, res, body) {
        if (err) {
            callback(err);
        } else {
            var success = res.statusCode == 200;
            if (success) {
                var data = JSON.parse(body).map(function (data) {
                    return {
                        name: data.name,
                        full_name: data.full_name,
                        private: data.private,
                        description: data.description,
                        url: data.url,
                        fork: data.fork
                    };
                });
                callback(null, data);
            } else {
                callback(new Error('Request failed with status: ' + res.statusCode));
            }
        }
    });
}

module.exports = listOrgRepo;
